==> perl-5.13.5.tar.gz: perl-5.13.5/cpan/Unicode-Collate/Collate/Locale/et.pl <==
+{
   entry => <<'ENTRY', # for DUCET v5.2.0
0161      ; [.1430.0020.0002.0161] # LATIN SMALL LETTER S WITH CARON
0073 030C ; [.1430.0020.0002.0161] # LATIN SMALL LETTER S WITH CARON
0160      ; [.1430.0020.0008.0160] # LATIN CAPITAL LETTER S WITH CARON
0053 030C ; [.1430.0020.0008.0160] # LATIN CAPITAL LETTER S WITH CARON
007A      ; [.1431.0020.0002.007A] # LATIN SMALL LETTER Z
005A      ; [.1431.0020.0008.005A] # LATIN CAPITAL LETTER Z
017E      ; [.1432.0020.0002.017E] # LATIN SMALL LETTER Z WITH CARON
007A 030C ; [.1432.0020.0002.017E] # LATIN SMALL LETTER Z WITH CARON
017D      ; [.1432.0020.0008.017D] # LATIN CAPITAL LETTER Z WITH CARON
005A 030C ; [.1432.0020.0008.017D] # LATIN CAPITAL LETTER Z WITH CARON
0077      ; [.147B.0021.0002.0077] # LATIN SMALL LETTER W
0057      ; [.147B.0021.0008.0057] # LATIN CAPITAL LETTER W
00F5      ; [.1493.0020.0002.00F5] # LATIN SMALL LETTER O WITH TILDE
006F 0303 ; [.1493.0020.0002.00F5] # LATIN SMALL LETTER O WITH TILDE
00D5      ; [.1493.0020.0008.00D5] # LATIN CAPITAL LETTER O WITH TILDE
004F 0303 ; [.1493.0020.0008.00D5] # LATIN CAPITAL LETTER O WITH TILDE
00E4      ; [.1494.0020.0002.00E4] # LATIN SMALL LETTER A WITH DIAERESIS
0061 0308 ; [.1494.0020.0002.00E4] # LATIN SMALL LETTER A WITH DIAERESIS
00C4      ; [.1494.0020.0008.00C4] # LATIN CAPITAL LETTER A WITH DIAERESIS
0041 0308 ; [.1494.0020.0008.00C4] # LATIN CAPITAL LETTER A WITH DIAERESIS
01DF      ; [.1494.0020.0002.00E4][.0000.005B.0002.0304] # LATIN SMALL LETTER A WITH DIAERESIS AND MACRON
01DE      ; [.1494.0020.0008.00C4][.0000.005B.0002.0304] # LATIN CAPITAL LETTER A WITH DIAERESIS AND MACRON
00F6      ; [.1495.0020.0002.00F6] # LATIN SMALL LETTER O WITH DIAERESIS
006F 0308 ; [.1495.0020.0002.00F6] # LATIN SMALL LETTER O WITH DIAERESIS
00D6      ; [.1495.0020.0008.00D6] # LATIN CAPITAL LETTER O WITH DIAERESIS
004F 0308 ; [.1495.0020.0008.00D6] # LATIN CAPITAL LETTER O WITH DIAERESIS
022B      ; [.1495.0020.0002.00F6][.0000.005B.0002.0304] # LATIN SMALL LETTER O WITH DIAERESIS AND MACRON
022A      ; [.1495.0020.0008.00D6][.0000.005B.0002.0304] # LATIN CAPITAL LETTER O WITH DIAERESIS AND MACRON
00FC      ; [.1496.0020.0002.00FC] # LATIN SMALL LETTER U WITH DIAERESIS
0075 0308 ; [.1496.0020.0002.00FC] # LATIN SMALL LETTER U WITH DIAERESIS
00DC      ; [.1496.0020.0008.00DC] # LATIN CAPITAL LETTER U WITH DIAERESIS
0055 0308 ; [.1496.0020.0008.00DC] # LATIN CAPITAL LETTER U WITH DIAERESIS
01DC      ; [.1496.0020.0002.00FC][.0000.0035.0002.0300] # LATIN SMALL LETTER U WITH DIAERESIS AND GRAVE
01DB      ; [.1496.0020.0008.00DC][.0000.0035.0002.0300] # LATIN CAPITAL LETTER U WITH DIAERESIS AND GRAVE
01D8      ; [.1496.0020.0002.00FC][.0000.0032.0002.0301] # LATIN SMALL LETTER U WITH DIAERESIS AND ACUTE
01D7      ; [.1496.0020.0008.00DC][.0000.0032.0002.0301] # LATIN CAPITAL LETTER U WITH DIAERESIS AND ACUTE
01D6      ; [.1496.0020.0002.00FC][.0000.005B.0002.0304] # LATIN SMALL LETTER U WITH DIAERESIS AND MACRON
01D5      ; [.1496.0020.0008.00DC][.0000.005B.0002.0304] # LATIN CAPITAL LETTER U WITH DIAERESIS AND MACRON
01DA      ; [.1496.0020.0002.00FC][.0000.0041.0002.030C] # LATIN SMALL LETTER U WITH DIAERESIS AND CARON
01D9      ; [.1496.0020.0008.00DC][.0000.0041.0002.030C] # LATIN CAPITAL LETTER U WITH DIAERESIS AND CARON
ENTRY
};

==> perl-5.13.7.tar.gz: perl-5.13.7/cpan/Unicode-Collate/Collate/Locale/et.pl <==
+{
   entry => <<'ENTRY', # for DUCET v5.2.0
0161      ; [.1430.0020.0002.0161] # LATIN SMALL LETTER S WITH CARON
0073 030C ; [.1430.0020.0002.0161] # LATIN SMALL LETTER S WITH CARON
0160      ; [.1430.0020.0008.0160] # LATIN CAPITAL LETTER S WITH CARON
0053 030C ; [.1430.0020.0008.0160] # LATIN CAPITAL LETTER S WITH CARON
007A      ; [.1431.0020.0002.007A] # LATIN SMALL LETTER Z
005A      ; [.1431.0020.0008.005A] # LATIN CAPITAL LETTER Z
017E      ; [.1432.0020.0002.017E] # LATIN SMALL LETTER Z WITH CARON
007A 030C ; [.1432.0020.0002.017E] # LATIN SMALL LETTER Z WITH CARON
017D      ; [.1432.0020.0008.017D] # LATIN CAPITAL LETTER Z WITH CARON
005A 030C ; [.1432.0020.0008.017D] # LATIN CAPITAL LETTER Z WITH CARON
0077      ; [.147B.0021.0002.0077] # LATIN SMALL LETTER W
0057      ; [.147B.0021.0008.0057] # LATIN CAPITAL LETTER W
00F5      ; [.1493.0020.0002.00F5] # LATIN SMALL LETTER O WITH TILDE
006F 0303 ; [.1493.0020.0002.00F5] # LATIN SMALL LETTER O WITH TILDE
00D5      ; [.1493.0020.0008.00D5] # LATIN CAPITAL LETTER O WITH TILDE
004F 0303 ; [.1493.0020.0008.00D5] # LATIN CAPITAL LETTER O WITH TILDE
1E4D      ; [.1493.0020.0002.00F5][.0000.0032.0002.0301] # LATIN SMALL LETTER O WITH TILDE AND ACUTE
1E4C      ; [.1493.0020.0008.00D5][.0000.0032.0002.0301] # LATIN CAPITAL LETTER O WITH TILDE AND ACUTE
022D      ; [.1493.0020.0002.00F5][.0000.005B.0002.0304] # LATIN SMALL LETTER O WITH TILDE AND MACRON
022C      ; [.1493.0020.0008.00D5][.0000.005B.0002.0304] # LATIN CAPITAL LETTER O WITH TILDE AND MACRON
1E4F      ; [.1493.0020.0002.00F5][.0000.0047.0002.0308] # LATIN SMALL LETTER O WITH TILDE AND DIAERESIS
1E4E      ; [.1493.0020.0008.00D5][.0000.0047.0002.0308] # LATIN CAPITAL LETTER O WITH TILDE AND DIAERESIS
1EE1      ; [.1493.0020.0002.00F5][.0000.0068.0002.031B] # LATIN SMALL LETTER O WITH HORN AND TILDE
1EE0      ; [.1493.0020.0008.00D5][.0000.0068.0002.031B] # LATIN CAPITAL LETTER O WITH HORN AND TILDE
00E4      ; [.1494.0020.0002.00E4] # LATIN SMALL LETTER A WITH DIAERESIS
0061 0308 ; [.1494.0020.0002.00E4] # LATIN SMALL LETTER A WITH DIAERESIS
00C4      ; [.1494.0020.0008.00C4] # LATIN CAPITAL LETTER A WITH DIAERESIS
0041 0308 ; [.1494.0020.0008.00C4] # LATIN CAPITAL LETTER A WITH DIAERESIS
01DF      ; [.1494.0020.0002.00E4][.0000.005B.0002.0304] # LATIN SMALL LETTER A WITH DIAERESIS AND MACRON
01DE      ; [.1494.0020.0008.00C4][.0000.005B.0002.0304] # LATIN CAPITAL LETTER A WITH DIAERESIS AND MACRON
00F6      ; [.1495.0020.0002.00F6] # LATIN SMALL LETTER O WITH DIAERESIS
006F 0308 ; [.1495.0020.0002.00F6] # LATIN SMALL LETTER O WITH DIAERESIS
00D6      ; [.1495.0020.0008.00D6] # LATIN CAPITAL LETTER O WITH DIAERESIS
004F 0308 ; [.1495.0020.0008.00D6] # LATIN CAPITAL LETTER O WITH DIAERESIS
022B      ; [.1495.0020.0002.00F6][.0000.005B.0002.0304] # LATIN SMALL LETTER O WITH DIAERESIS AND MACRON
022A      ; [.1495.0020.0008.00D6][.0000.005B.0002.0304] # LATIN CAPITAL LETTER O WITH DIAERESIS AND MACRON
00FC      ; [.1496.0020.0002.00FC] # LATIN SMALL LETTER U WITH DIAERESIS
0075 0308 ; [.1496.0020.0002.00FC] # LATIN SMALL LETTER U WITH DIAERESIS
00DC      ; [.1496.0020.0008.00DC] # LATIN CAPITAL LETTER U WITH DIAERESIS
0055 0308 ; [.1496.0020.0008.00DC] # LATIN CAPITAL LETTER U WITH DIAERESIS
01DC      ; [.1496.0020.0002.00FC][.0000.0035.0002.0300] # LATIN SMALL LETTER U WITH DIAERESIS AND GRAVE
01DB      ; [.1496.0020.0008.00DC][.0000.0035.0002.0300] # LATIN CAPITAL LETTER U WITH DIAERESIS AND GRAVE
01D8      ; [.1496.0020.0002.00FC][.0000.0032.0002.0301] # LATIN SMALL LETTER U WITH DIAERESIS AND ACUTE
01D7      ; [.1496.0020.0008.00DC][.0000.0032.0002.0301] # LATIN CAPITAL LETTER U WITH DIAERESIS AND ACUTE
01D6      ; [.1496.0020.0002.00FC][.0000.005B.0002.0304] # LATIN SMALL LETTER U WITH DIAERESIS AND MACRON
01D5      ; [.1496.0020.0008.00DC][.0000.005B.0002.0304] # LATIN CAPITAL LETTER U WITH DIAERESIS AND MACRON
01DA      ; [.1496.0020.0002.00FC][.0000.0041.0002.030C] # LATIN SMALL LETTER U WITH DIAERESIS AND CARON
01D9      ; [.1496.0020.0008.00DC][.0000.0041.0002.030C] # LATIN CAPITAL LETTER U WITH DIAERESIS AND CARON
ENTRY
};
